@@ -2,6 +2,26 @@
 import subprocess
 import sys
 import os
+import importlib
+import tomllib  # Python 3.11+
+from pathlib import Path
+
+def install_package(package):
+    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+
+try:
+    importlib.import_module('rich')
+except ImportError:
+    print("[yellow]⚙️ Installation du package rich...[/]")
+    install_package('rich')
+
+from rich import print
+
+def get_version():
+    pyproject_path = Path(__file__).resolve().parent.parent / "pyproject.toml"
+    with open(pyproject_path, "rb") as f:
+        data = tomllib.load(f)
+    return data["project"]["version"]
 
 def run_script(script_name, arg=None):
     script_dir = os.path.dirname(os.path.abspath(__file__))  # = src/
@@ -13,16 +33,17 @@ def run_script(script_name, arg=None):
 
     result = subprocess.run(cmd, check=True)
     if result.returncode != 0:
-        print(f"❌ Le script {script_name} a échoué avec le code {result.returncode}")
+        print(f"[bold red]❌ Le script {script_name} a échoué avec le code {result.returncode}[/]")
         sys.exit(result.returncode)
 
 def main():
-    print("\n🎉 Bienvenue dans OpenStack Toolbox v1.3 🎉")
-    print("Commandes disponibles :")
-    print("  • openstack_summary        → Génère un résumé global du projet")
-    print("  • openstack_optimization   → Identifie les ressources sous-utilisées dans la semaine")
-    print("  • openstack_weekly_notification   → Paramètre l'envoi d'un e-mail avec le résumé de la semaine")
-    
+    version = get_version()
+    print(f"\n[bold yellow]🎉 Bienvenue dans OpenStack Toolbox v{version} 🎉[/]")
+    print("[cyan]Commandes disponibles :[/]")
+    print("  • [bold]openstack_summary[/]        → Génère un résumé global du projet")
+    print("  • [bold]openstack_optimization[/]   → Identifie les ressources sous-utilisées dans la semaine")
+    print("  • [bold]openstack_weekly_notification[/]   → Paramètre l'envoi d'un e-mail avec le résumé de la semaine")
+
     header = r"""
   ___                       _             _       
  / _ \ _ __   ___ _ __  ___| |_ __ _  ___| | __   
@@ -36,7 +57,7 @@ def main():
                                             |___/ 
             By Loutre
     """
-    print(header)
+    print(f"[bold blue]{header}[/]")
     run_script("fetch_billing.py")
     billing_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'billing.json')
     run_script("openstack_script.py", billing_file)
