@@ -1,25 +1,38 @@
+import getpass
 import smtplib
 from email.mime.text import MIMEText
 from email.mime.multipart import MIMEMultipart
 import os
 import sys
 import configparser
+import tomllib  # Python 3.11+
+from pathlib import Path
+from rich import print
 from notification import generate_report
-import argparse
-import subprocess
+from cron_notification import setup_cron
 
 CONFIG_PATH = os.path.expanduser("~/.openstack_toolbox_config.ini")
 
+def get_version():
+    pyproject_path = Path(__file__).resolve().parent.parent / "pyproject.toml"
+    with open(pyproject_path, "rb") as f:
+        data = tomllib.load(f)
+    return data["project"]["version"]
+
 def create_config_interactive():
-    print("🛠️ Configuration initiale SMTP nécessaire.")
+    print("[bold cyan]🛠️ Configuration initiale SMTP nécessaire.[/]")
     print("Merci de saisir les informations demandées pour configurer l'envoi d'e-mails.\n")
 
     smtp_server = input("SMTP server (ex: smtp.gmail.com): ").strip()
+    if smtp_server.lower() == "smtp.gmail.com":
+        print("[bold yellow]⚠️ Pour Gmail, vous devez activer la validation en 2 étapes et créer un mot de passe d’application.[/]")
+        print("Voici la page d’aide Google : https://support.google.com/accounts/answer/185833")
+        print("[bold yellow]⚠️ Pour Gmail, utilisez un mot de passe d’application, pas votre mot de passe habituel.[/]")
     smtp_port = input("SMTP port (ex: 587): ").strip()
     smtp_username = input("SMTP username (votre login email): ").strip()
-    smtp_password = input("SMTP password (votre mot de passe email): ").strip()
-    from_email = input("From email (adresse expéditeur): ").strip()
-    to_email = input("To email (adresse destinataire): ").strip()
+    smtp_password = getpass.getpass("SMTP password (mot de passe email ou mot de passe d’application Gmail) : ").strip()
+    from_email = smtp_username  # l'adresse expéditeur = login SMTP
+    to_email = input("Adresse e-mail destinataire : ").strip()
 
     config = configparser.ConfigParser()
     config['SMTP'] = {
@@ -35,7 +48,7 @@ def create_config_interactive():
     with open(config_path, 'w') as configfile:
         config.write(configfile)
 
-    print(f"\n✅ Configuration sauvegardée dans {config_path}\n")
+    print(f"\n[bold green]✅ Configuration sauvegardée dans[/] [underline]{config_path}[/]\n")
 
 def load_config():
     config_path = os.path.expanduser("~/.openstack_toolbox_config.ini")
@@ -45,7 +58,7 @@ def load_config():
     config = configparser.ConfigParser()
     config.read(config_path)
     if 'SMTP' not in config:
-        print("❌ Section [SMTP] manquante dans le fichier de configuration.")
+        print("[bold red]❌ Section [SMTP] manquante dans le fichier de configuration.[/]")
         sys.exit(1)
     return config['SMTP']
 
@@ -59,7 +72,7 @@ def send_email(subject, body):
     to_email = smtp_config.get('to_email')
 
     if not all([smtp_server, smtp_port, smtp_username, smtp_password, from_email, to_email]):
-        print("❌ La configuration SMTP est incomplète dans le fichier de configuration.")
+        print("[bold red]❌ La configuration SMTP est incomplète dans le fichier de configuration.[/]")
         sys.exit(1)
 
     # Créer le message
@@ -77,41 +90,14 @@ def send_email(subject, body):
         server.login(smtp_username, smtp_password)
         server.send_message(msg)
 
-def setup_cron():
-    """Ajoute ce script à la crontab pour une exécution automatique chaque lundi à 8h."""
-    python_exe = sys.executable
-    script_path = os.path.abspath(__file__)
-    cron_line = f"0 8 * * 1 {python_exe} {script_path} > /dev/null 2>&1\n"
-
-    result = subprocess.run(['crontab', '-l'], capture_output=True, text=True)
-    existing_cron = result.stdout if result.returncode == 0 else ""
-
-    if cron_line.strip() in existing_cron:
-        print("✅ La tâche cron est déjà configurée.")
-        return
-
-    new_cron = existing_cron + cron_line
-    proc = subprocess.run(['crontab', '-'], input=new_cron, text=True)
-    if proc.returncode == 0:
-        print("✅ Tâche cron ajoutée : le script s'exécutera tous les lundis à 8h.")
-    else:
-        print("❌ Échec lors de l'ajout à la crontab.")
-
 def main():
-    parser = argparse.ArgumentParser()
-    parser.add_argument('--setup-cron', action='store_true', help="Ajoute une tâche cron pour lancer ce script chaque lundi à 8h.")
-    args = parser.parse_args()
-
-    if args.setup_cron:
-        setup_cron()
-        return
-
+    version = get_version()
     # Afficher le message d'accueil
-    print("\n🎉 Bienvenue dans OpenStack Toolbox v1.3 🎉")
-    print("Commandes disponibles :")
-    print("  • openstack_summary        → Génère un résumé global du projet")
-    print("  • openstack_optimization   → Identifie les ressources sous-utilisées et propose un résumé de la semaine")
-    print("  • openstack_weekly_notification   → Paramètre l'envoi d'un e-mail avec le résumé de la semaine")
+    print(f"\n[bold yellow]🎉 Bienvenue dans OpenStack Toolbox v{version} 🎉[/]")
+    print("[cyan]Commandes disponibles :[/]")
+    print("  • [bold]openstack_summary[/]        → Génère un résumé global du projet")
+    print("  • [bold]openstack_optimization[/]   → Identifie les ressources sous-utilisées et propose un résumé de la semaine")
+    print("  • [bold]openstack_weekly_notification[/]   → Paramètre l'envoi d'un e-mail avec le résumé de la semaine")
 
     header = r"""
   ___                       _             _          
@@ -138,11 +124,32 @@ _\___/| .__/ \___|_|_|_|___/\__\__,_|\___|_|\_\
             "Rapport hebdomadaire : Infomaniak Openstack Optimisation",
             email_body
         )
-        print("✅ Email envoyé avec succès.")
+        print("[bold green]✅ Email envoyé avec succès.[/]")
     except FileNotFoundError:
-        print("❌ Le fichier de rapport est introuvable.")
+        print("[bold red]❌ Le fichier de rapport est introuvable.[/]")
     except Exception as e:
-        print(f"❌ Erreur lors de l'envoi de l'email : {e}")
+        print(f"[bold red]❌ Erreur lors de l'envoi de l'email :[/] {e}")
+        print("[bold yellow]💡 Vérifiez que votre configuration SMTP est correcte.[/]")
+        print("Souhaitez-vous reconfigurer maintenant et envoyer un e-mail test ? (o/n)")
+        retry = input().strip().lower()
+        if retry == 'o':
+            create_config_interactive()
+            try:
+                send_email("Test SMTP - OpenStack Toolbox", "✅ Ceci est un e-mail test de la configuration SMTP.")
+                print("[bold green]📬 E-mail test envoyé avec succès.[/]")
+            except Exception as e:
+                print(f"[bold red]❌ L'envoi de l'e-mail test a échoué :[/] {e}")
+                print("[bold cyan]ℹ️ Veuillez vérifier vos identifiants ou paramètres SMTP.[/]")
+        else:
+            print("[bold cyan]ℹ️ Vous pouvez relancer ce script plus tard après correction de la configuration.[/]")
+
+    print("\n💌 Voulez-vous paramétrer l'envoi hebdomadaire d'un e-mail avec le résumé de la semaine ? (o/n)")
+    choice = input().strip().lower()
+    if choice == 'o':
+        setup_cron()
+        print("[bold green]✅ Configuration terminée. Vous pouvez maintenant envoyer des e-mails.[/]")
+    else:
+        print("[bold yellow]❌ Configuration annulée.[/]")
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
